# Sensu Go Jira Handler

The [Sensu Go][3] [Jira][4] handler is a [Sensu Event Handler][5] that creates or updates a Jira issue.

## Configuration

Example Sensu Go definition:

```json
{
    "api_version": "core/v2",
    "type": "Handler",
    "metadata": {
        "namespace": "default",
        "name": "jira"
    },
    "spec": {
        "type": "pipe",
        "command": "sensu-jira-handler --jira-url 'https://example.atlassian.net' --jira-project-key SEN --jira-username 'sensu@example.com' --jira-password 'secret' --jira-issue-type 'Bug'",
        "timeout": 10,
        "filters": [
            "is_incident"
        ]
    }
}
```

## Usage Examples

### Help:

```
The Sensu Go Jira Handler

Usage:
  sensu-jira-handler [flags]

Flags:
  -h, --help                           help for sensu-jira-handler
  -P, --http-proxy string              The HTTP Proxy if necessary (ex. 'http://proxyhost:8080')
  -T, --http-timeout int               The HTTP timeout
  -t, --jira-issue-type string         The type of Jira issue to create
  -p, --jira-password string           The Jira password
  -k, --jira-project-key string        The Jira project key
  -n, --jira-project-name string       The Jira project name
  -s, --jira-resolution-state string   The key of the status to transition the issue to when resolving it
  -U, --jira-url string                The Jira URL
  -u, --jira-username string           The Jira usernane
  -v, --verbose                        Verbose mode
```

### Authenticating Using Jira's Cloud Version

While the on-premise version of Jira uses basic HTTP authentication with only a simple username and password the cloud 
version requires the use of an API token to authenticate. To create the API token perform the following steps:

1. Navigate to [Atlassian's API Tokens Screen][2]
1. Click on the `Create API Token` button
1. In the popup box enter `Sensu Jira Handler` or any label of your liking
1. Click on the `Create` button
1. Click on `Copy to clipboard` to copy your token

The token copied becomes the password you use to authenticate using the `--jira-password` or `-p` option.

Example:

```bash
sensu-jira-handler --jira-username your@email.com --jira-password xwBPFTG0s9zYgTfkFsK6505E ... 
```

or

```bash
sensu-jira-handler -u your@email.com -p xwBPFTG0s9zYgTfkFsK6505E ... 
```

### Resolving Issue Configuration

This Jira handler sets the `resolution` to done when resolving an issue. To make sure this works a screen with the `resolution` 
needs to be configured in the transition to the `Done` state. If this is not setup correctly the issue resolution will fail.   

[1]: https://github.com/sensu/sensu-jira-handler/releases
[2]: https://id.atlassian.com/manage/api-tokens
[3]: https://github.com/sensu/sensu-go
[4]: https://www.atlassian.com/software/jira
[5]: https://docs.sensu.io/sensu-go/5.0/reference/handlers/#how-do-sensu-handlers-work
